<?php
/* PLOP DS サンプルスクリプト simple_sig.php
 * PDFlib 入門で作成した hello-j.pdf に電子署名を施します
 * ※ BOM なし UTF-8 で保存してください
 *    (notepad で保存すると BOM が付いてしまいます)
 * ※ 電子署名は PLOP DS に同梱されている demorsa2048.p12 を使います。
 *    demo_signer_rsa_2048.p12 は data ディレクトリにあります。
 *    demo_signer_rsa_2048.p12 のパスワードは demo です。
 */

/* 入力ファイル等のディレクトリとファイル名を指定
 * (環境に合わせて書き換えてください)
 */
$input_dir = __DIR__;
$input = "hello-j.pdf";
$sign_dir = __DIR__ . "/../data";
$sign = "demo_signer_rsa_2048.p12";
$sign_image = "signature.pdf";
$output = "simple_sig.pdf";

/* PLOP オブジェクトを作成 */
$plop = new PLOP();

/* 上記で指定したディレクトリを検索対象に設定 */
$plop->set_option("searchpath=$input_dir");
$plop->set_option("searchpath=$sign_dir");

/* 入力ファイルと署名イメージの PDF を開く */
$doc = $plop->open_document($input, "");
$vis_doc = $plop->open_document($sign_image, "");

/* 電子署名する際のオプションを設定する */
$sign_opts =
    "engine=builtin " .
    "digitalid={filename={$sign}} " .
    "password={demo} " .
    "field={name=Signature1 rect={30 770 80 820} visdoc=$vis_doc} " .
    "reason=\xEF\xBB\xBF文書を証明する " .
    "location=\xEF\xBB\xBFインフォテック（株） ";
$plop->prepare_signature($sign_opts);

/* 電子署名を施した PDF を作成し、そのバッファを取得する */
$plop->create_document("", "input=$doc");
$buf = $plop->get_buffer();

/* 開いたファイルを閉じ、plop オブジェクトを破棄する */
$plop->close_document($vis_doc, "");
$plop->close_document($doc, "");
$plop = 0;

/* 作成した PDF のバッファをブラウザに返す */
$len = strlen($buf);
header("Content-type: application/pdf");
header("Content-Length: $len");
header("Content-Disposition: inline; filename=$output");
print $buf;

